@x  Module   61
@ The evaluation of the power series is done by calling
the |ps_eval| routine.  This is quite simple in the initial
value problem.  It would be in a loop on the boundary value case.

The |if|'s are separate because both may need evaluation.
@^Parallel considerations@>

@<Evaluate the power series@>=
      do i = 0, max_ivp
        do j = 1, n_
          if( evaluate_derivative ) then
            call ps_eval_d(PS(0,j,i), m_ , tau, DP(j,i))
            end if
          if( evaluate_function ) then
            call ps_eval(PS(0,j,i), m_ , tau, P(j,i))
            end if
          end do
        end do
@y  Module   61
@ The evaluation of the power series is done by calling
the |ps_eval| routine.  This is quite simple in the initial
value problem.  It would be in a loop on the boundary value case.

We also calculate the derivatives for special need in this
testing.

The |if|'s are separate because both may need evaluation.
@^Parallel considerations@>

@<Evaluate the power series@>=
      if( at_output ) evaluate_derivative = .true.
      do i = 0, max_ivp
        do j = 1, n_
          if( evaluate_derivative ) then
            call ps_eval_d(PS(0,j,i), m_ , tau, DP(j,i))
            end if
          if( evaluate_function ) then
            call ps_eval(PS(0,j,i), m_ , tau, P(j,i))
            end if
          end do
        end do
@z  Module   61


@x  Module   65
@ When we reach a regular output point, we simply output the results.
It may be that these would also be written to a file for later
graphics use.  When one of these is used, the value of |t_output| must
be updated.

The initial values are output elsewhere and cannot be supressed.
The parameters are also output at the point where we `start the
output.'  After the start of the output, we output only the 
elements of the ODE's that may change, in other words we don't
output the constant coefficients or parameters.

@^Application dependencies@>
@<Output the results, regularly@>=
      if( t.eq.t_output_start ) then
        n_out = n_
      else
        n_out = n_ode
        end if
      if( (t.ge.t_output_start).and.(t.gt.t_start) ) then
        write(*,format_t_y) t, (P(j,0),j=1,n_out)
        @<Debug output? All particular solutions@>
        end if
      t_output = t_output + t_output_delta
      at_output = .false.
@y  Module   65
@ When we reach a regular output point, we simply output the results.
It may be that these would also be written to a file for later
graphics use.  When one of these is used, the value of |t_output| must
be updated.

When we are at the start of output, we output the entire vector which
includes the parameters.  After the start of the solution
we output only the ODE's that may change.

We also output the derivative term which is the only reason this module
was changed.
@^Application dependencies@>
@<Output the results, regularly@>=
      if( t.eq.t_output_start ) then
        n_out = n_
      else
        n_out = n_ode
        end if
      if( t.gt.t_output_start) then
        write(*,format_t_y) t, (P(j,0),j=1,n_out), DP(2,0)
        @<Debug output? All particular solutions@>
        end if
      t_output = t_output + t_output_delta
      at_output = .false.
@z  Module   65

@x  Module  198
@* Modules that change: the ODEs. 
The modules that may need changing for different sets of
differential equations or because of the number of of
boundary conditions.  The |parameter|s are set in module
\the\parametermodule{}.  This module is included in the
source for the linear equation solver.
The differential equations are codes from here to the end.

If someone is using this in production environments, it is
recommended that this major section be an include file.
The \fweb{} allows this, but we have included this code
directly to ease the distribution of the sources.

The differential equation that is being solved was presented
in modules \the\nlbvpmodule{} and \the\firstorder.

For linear problems there is one set of equations and the |else| clause
of the |if - then - else| can be eliminated.  Common calculations for
forcing functions or variable coefficients are placed in the first
part of the conditional.  For nonlinear ODEs, the |if - then| clause
also contains the base equations and the |else| clause contains the
linearized equations.  These linearized equations can be put onto
separate processors. Each processor would process the recurrence
equations in a loop on |k|.  Further, these are nested in the loop
through the particular solutions, a loop on |i|, and each
|i.gt.0| is what can be assigned to separate processors.
@^Application dependencies@>
@^ODE@>
@^The governing equations@>
@^Power series@>

@<Calculate the |k|-th term of the power series@>=
      if( i.eq.0 .or. scoring .gt. 0 ) then
        @<Do common calculations@>
        end if
      PS(k,1,i) = PS(k-1,2,i)/(k)
      PS(k,2,i) = (-xi*PS(k-1,1,i)-mu*PS(k-1,2,i)+sn(k-1))/(k)
@y  Module  198
@* Modules that change: the ODEs. 
The modules that may need changing for different sets of
differential equations or because of the number of of
boundary conditions.  The |parameter|s are set in module
\the\parametermodule{}.  This module is included in the
source for the linear equation solver.
The differential equations are codes from here to the end.

If someone is using this in production environments, it is
recommended that this major section be an include file.
The \fweb{} allows this, but we have included this code
directly to ease the distribution of the sources.

The differential equation that is being solved was presented
in modules \the\nlbvpmodule{} and \the\firstorder.

For linear problems there is one set of equations and the |else| clause
of the |if - then - else| can be eliminated.  Common calculations for
forcing functions or variable coefficients are placed in the first
part of the conditional.  For nonlinear ODEs, the |if - then| clause
also contains the base equations and the |else| clause contains the
linearized equations.  These linearized equations can be put onto
separate processors. Each processor would process the recurrence
equations in a loop on |k|.  Further, these are nested in the loop
through the particular solutions, a loop on |i|, and each
|i.gt.0| is what can be assigned to separate processors.
@^Application dependencies@>
\newcount\odemodule
\odemodule=\modno
@^ODE@>
@^The governing equations@>
@^Power series@>

{\it The rules and arrows, $\Downarrow\Uparrow$,
delimit \TeX{} source that in the future will automatically be
converted to the \Fortran{} or \Cee{} code through the use of
symbolic computations.  The code in this and the next module are
specified by this.}  The parameter estimation problem uses
$\mu \equiv y_3$, $\xi \equiv y_4$, and $\lambda\equiv y_5$. Thus:
\BEGINsym
\begin{eqnarray}
\dot y_1 & = y_2\\
\dot y_2 & = -y_4 y_1 - y_3 y_2 + y_5 \sin(t)\\
\end{eqnarray}
\ENDsym
The linearized form (which will also be automatically generated) of
these equations was given in equations~21.
@^Symbolic computations@>

@<Calculate the |k|-th term of the power series@>=
      if( i.eq.0 .or. scoring .gt. 0 ) then
        @<Do common calculations@>
        PS(k,1,i) = PS(k-1,2,i)/(k)
        PS(k,2,i) = (-forcing(k-1) + PS(0,5,i)*sn(k-1))/(k)
      else
        PS(k,1,i) = PS(k-1,2,i)/(k)
        tmp = forcing(k-1) + PS(  0,5,i)*sn(k-1)
        tmp = tmp - PS(  0,4,0)*PS(k-1,1,i) - PS(  0,3,0)*PS(k-1,2,i)
        tmp = tmp - PS(k-1,1,0)*PS(  0,4,i) - PS(k-1,2,0)*PS(  0,3,i)
        PS(k,2,i) = tmp / (k)
        end if
@z  Module  198

@x  Module  199
@ These calculations are independent of which solution of the
ODE it is.  These are usually the forcing functions or variable
coefficients that need not be calculated more than once.
@^Application dependencies@>

@<Do common calculations@>=
      call ps_trig(t_ps,k-1,sn,cs)
@y  Module  199
@ These calculations are independent of which solution of the
ODE it is.  These are usually the forcing functions or variable
coefficients that need not be calculated more than once.

The linear version of this problem used |ps_trig| and this nonlinear
version is more efficient by the separate calculation of |forcing|.
@^Application dependencies@>

@<Do common calculations@>=
      call ps_trig(t_ps,k-1,sn,cs)
      forcing(k-1)= PS(0,4,i)*PS(k-1,1,i) + PS(0,3,i)*PS(k-1,2,i)
@z  Module  199

@x  Module  200
@ We need to declare the variable for $\mu$ and $\xi$.
The series |sn| and |cs| represent the independent
variable |t| and the sine and cosine of |t|, respectively.
@^Application dependencies@>

@<Quasi's local variables@>=
      floating  mu, xi, sn(0:m_), cs(0:m_)
      parameter (mu=0.05,xi=1.0)
@y  Module  200
@ We will not declare the variable for $\mu$ and $\xi$ because
they are now part of the state vector |y|..
The series |sn| and |cs| represent the independent
variable |t| and the sine and cosine of |t|, respectively.
The variable, |forcing|, is the resulting forcing function
that comes from the linearization and the original external
forcing function.  It is calculated along with the other
`common' calculations and used in each of the linearized solutions.
@^Application dependencies@>

@<Quasi's local variables@>=
      floating sn(0:m_), cs(0:m_), tmp, forcing(0:m_)
@z  Module  200
